/*******************************************************************************
 * University of Illinois/NCSA
 * Open Source License
 *
 * Copyright (c) 2010 , NCSA.  All rights reserved.
 *
 * Developed by:
 * Cyberenvironments and Technologies (CET)
 * http://cet.ncsa.illinois.edu/
 *
 * National Center for Supercomputing Applications (NCSA)
 * http://www.ncsa.illinois.edu/
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal with the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimers.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimers in the
 *   documentation and/or other materials provided with the distribution.
 * - Neither the names of CET, University of Illinois/NCSA, nor the names
 *   of its contributors may be used to endorse or promote products
 *   derived from this Software without specific prior written permission.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 *******************************************************************************/
package edu.uiuc.ncsa.cet.bean.workflow;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

import edu.uiuc.ncsa.cet.bean.CETBean;
import edu.uiuc.ncsa.cet.bean.DatasetBean;

public class DatasetListBean extends CETBean implements Serializable {
    /** Used for serialization of object */
    private static final long serialVersionUID = 1L;

    /** id of the list of datasets, this matches to the id in tooldata */
    private String            id               = UUID.randomUUID().toString();

    /** list of datasets associated with this id */
    private List<DatasetBean> data             = new ArrayList<DatasetBean>();

    /**
     * Create a new instance of the list of datasets.
     */
    public DatasetListBean() {
    }

    /**
     * Returns the id of datasets.
     * 
     * @return the id of datasets.
     */
    public String getId() {
        return id;
    }

    /**
     * Sets the id of datasets.
     * 
     * @param id
     *            the id of datasets.
     */
    public void setId(String id) {
        this.id = id;
    }

    /**
     * Returns the list of datasets.
     * 
     * @return the list of datasets.
     */
    public List<DatasetBean> getData() {
        return data;
    }

    /**
     * Sets the list of datasets.
     * 
     * @param data
     *            the list of datasets.
     */
    public void setData(List<DatasetBean> data) {
        this.data.clear();
        if (data != null) {
            this.data.addAll(data);
        }
    }

    /**
     * Add data to the list of datasets
     * 
     * @param data
     *            the data to be added.
     */
    public void addData(DatasetBean data) {
        this.data.add(data);
    }

    /**
     * Remove data to from the list of datasets
     * 
     * @param data
     *            the data to be removed.
     */
    public void removeData(DatasetBean data) {
        this.data.remove(data);
    }
}
